"""
Type annotations for voice-id service type definitions.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from mypy_boto3_voice_id.type_defs import AssociateFraudsterRequestTypeDef

    data: AssociateFraudsterRequestTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import (
    AuthenticationDecisionType,
    DomainStatusType,
    DuplicateRegistrationActionType,
    ExistingEnrollmentActionType,
    FraudDetectionActionType,
    FraudDetectionDecisionType,
    FraudDetectionReasonType,
    FraudsterRegistrationJobStatusType,
    ServerSideEncryptionUpdateStatusType,
    SpeakerEnrollmentJobStatusType,
    SpeakerStatusType,
    StreamingStatusType,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Sequence
else:
    from typing import Dict, List, Sequence
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict

__all__ = (
    "AssociateFraudsterRequestTypeDef",
    "AssociateFraudsterResponseTypeDef",
    "AuthenticationConfigurationTypeDef",
    "AuthenticationResultTypeDef",
    "CreateDomainRequestTypeDef",
    "CreateDomainResponseTypeDef",
    "CreateWatchlistRequestTypeDef",
    "CreateWatchlistResponseTypeDef",
    "DeleteDomainRequestTypeDef",
    "DeleteFraudsterRequestTypeDef",
    "DeleteSpeakerRequestTypeDef",
    "DeleteWatchlistRequestTypeDef",
    "DescribeDomainRequestTypeDef",
    "DescribeDomainResponseTypeDef",
    "DescribeFraudsterRegistrationJobRequestTypeDef",
    "DescribeFraudsterRegistrationJobResponseTypeDef",
    "DescribeFraudsterRequestTypeDef",
    "DescribeFraudsterResponseTypeDef",
    "DescribeSpeakerEnrollmentJobRequestTypeDef",
    "DescribeSpeakerEnrollmentJobResponseTypeDef",
    "DescribeSpeakerRequestTypeDef",
    "DescribeSpeakerResponseTypeDef",
    "DescribeWatchlistRequestTypeDef",
    "DescribeWatchlistResponseTypeDef",
    "DisassociateFraudsterRequestTypeDef",
    "DisassociateFraudsterResponseTypeDef",
    "DomainSummaryTypeDef",
    "DomainTypeDef",
    "EmptyResponseMetadataTypeDef",
    "EnrollmentConfigOutputTypeDef",
    "EnrollmentConfigTypeDef",
    "EnrollmentConfigUnionTypeDef",
    "EnrollmentJobFraudDetectionConfigOutputTypeDef",
    "EnrollmentJobFraudDetectionConfigTypeDef",
    "EvaluateSessionRequestTypeDef",
    "EvaluateSessionResponseTypeDef",
    "FailureDetailsTypeDef",
    "FraudDetectionConfigurationTypeDef",
    "FraudDetectionResultTypeDef",
    "FraudRiskDetailsTypeDef",
    "FraudsterRegistrationJobSummaryTypeDef",
    "FraudsterRegistrationJobTypeDef",
    "FraudsterSummaryTypeDef",
    "FraudsterTypeDef",
    "InputDataConfigTypeDef",
    "JobProgressTypeDef",
    "KnownFraudsterRiskTypeDef",
    "ListDomainsRequestPaginateTypeDef",
    "ListDomainsRequestTypeDef",
    "ListDomainsResponseTypeDef",
    "ListFraudsterRegistrationJobsRequestPaginateTypeDef",
    "ListFraudsterRegistrationJobsRequestTypeDef",
    "ListFraudsterRegistrationJobsResponseTypeDef",
    "ListFraudstersRequestPaginateTypeDef",
    "ListFraudstersRequestTypeDef",
    "ListFraudstersResponseTypeDef",
    "ListSpeakerEnrollmentJobsRequestPaginateTypeDef",
    "ListSpeakerEnrollmentJobsRequestTypeDef",
    "ListSpeakerEnrollmentJobsResponseTypeDef",
    "ListSpeakersRequestPaginateTypeDef",
    "ListSpeakersRequestTypeDef",
    "ListSpeakersResponseTypeDef",
    "ListTagsForResourceRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "ListWatchlistsRequestPaginateTypeDef",
    "ListWatchlistsRequestTypeDef",
    "ListWatchlistsResponseTypeDef",
    "OptOutSpeakerRequestTypeDef",
    "OptOutSpeakerResponseTypeDef",
    "OutputDataConfigTypeDef",
    "PaginatorConfigTypeDef",
    "RegistrationConfigOutputTypeDef",
    "RegistrationConfigTypeDef",
    "RegistrationConfigUnionTypeDef",
    "ResponseMetadataTypeDef",
    "ServerSideEncryptionConfigurationTypeDef",
    "ServerSideEncryptionUpdateDetailsTypeDef",
    "SpeakerEnrollmentJobSummaryTypeDef",
    "SpeakerEnrollmentJobTypeDef",
    "SpeakerSummaryTypeDef",
    "SpeakerTypeDef",
    "StartFraudsterRegistrationJobRequestTypeDef",
    "StartFraudsterRegistrationJobResponseTypeDef",
    "StartSpeakerEnrollmentJobRequestTypeDef",
    "StartSpeakerEnrollmentJobResponseTypeDef",
    "TagResourceRequestTypeDef",
    "TagTypeDef",
    "UntagResourceRequestTypeDef",
    "UpdateDomainRequestTypeDef",
    "UpdateDomainResponseTypeDef",
    "UpdateWatchlistRequestTypeDef",
    "UpdateWatchlistResponseTypeDef",
    "VoiceSpoofingRiskTypeDef",
    "WatchlistDetailsTypeDef",
    "WatchlistSummaryTypeDef",
    "WatchlistTypeDef",
)

class AssociateFraudsterRequestTypeDef(TypedDict):
    DomainId: str
    FraudsterId: str
    WatchlistId: str

class FraudsterTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DomainId: NotRequired[str]
    GeneratedFraudsterId: NotRequired[str]
    WatchlistIds: NotRequired[List[str]]

class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]

class AuthenticationConfigurationTypeDef(TypedDict):
    AcceptanceThreshold: int

class ServerSideEncryptionConfigurationTypeDef(TypedDict):
    KmsKeyId: str

class TagTypeDef(TypedDict):
    Key: str
    Value: str

class CreateWatchlistRequestTypeDef(TypedDict):
    DomainId: str
    Name: str
    ClientToken: NotRequired[str]
    Description: NotRequired[str]

class WatchlistTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DefaultWatchlist: NotRequired[bool]
    Description: NotRequired[str]
    DomainId: NotRequired[str]
    Name: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    WatchlistId: NotRequired[str]

class DeleteDomainRequestTypeDef(TypedDict):
    DomainId: str

class DeleteFraudsterRequestTypeDef(TypedDict):
    DomainId: str
    FraudsterId: str

class DeleteSpeakerRequestTypeDef(TypedDict):
    DomainId: str
    SpeakerId: str

class DeleteWatchlistRequestTypeDef(TypedDict):
    DomainId: str
    WatchlistId: str

class DescribeDomainRequestTypeDef(TypedDict):
    DomainId: str

class DescribeFraudsterRegistrationJobRequestTypeDef(TypedDict):
    DomainId: str
    JobId: str

class DescribeFraudsterRequestTypeDef(TypedDict):
    DomainId: str
    FraudsterId: str

class DescribeSpeakerEnrollmentJobRequestTypeDef(TypedDict):
    DomainId: str
    JobId: str

class DescribeSpeakerRequestTypeDef(TypedDict):
    DomainId: str
    SpeakerId: str

class SpeakerTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    CustomerSpeakerId: NotRequired[str]
    DomainId: NotRequired[str]
    GeneratedSpeakerId: NotRequired[str]
    LastAccessedAt: NotRequired[datetime]
    Status: NotRequired[SpeakerStatusType]
    UpdatedAt: NotRequired[datetime]

class DescribeWatchlistRequestTypeDef(TypedDict):
    DomainId: str
    WatchlistId: str

class DisassociateFraudsterRequestTypeDef(TypedDict):
    DomainId: str
    FraudsterId: str
    WatchlistId: str

class ServerSideEncryptionUpdateDetailsTypeDef(TypedDict):
    Message: NotRequired[str]
    OldKmsKeyId: NotRequired[str]
    UpdateStatus: NotRequired[ServerSideEncryptionUpdateStatusType]

class WatchlistDetailsTypeDef(TypedDict):
    DefaultWatchlistId: str

class EnrollmentJobFraudDetectionConfigOutputTypeDef(TypedDict):
    FraudDetectionAction: NotRequired[FraudDetectionActionType]
    RiskThreshold: NotRequired[int]
    WatchlistIds: NotRequired[List[str]]

class EnrollmentJobFraudDetectionConfigTypeDef(TypedDict):
    FraudDetectionAction: NotRequired[FraudDetectionActionType]
    RiskThreshold: NotRequired[int]
    WatchlistIds: NotRequired[Sequence[str]]

class EvaluateSessionRequestTypeDef(TypedDict):
    DomainId: str
    SessionNameOrId: str

class FailureDetailsTypeDef(TypedDict):
    Message: NotRequired[str]
    StatusCode: NotRequired[int]

class FraudDetectionConfigurationTypeDef(TypedDict):
    RiskThreshold: NotRequired[int]
    WatchlistId: NotRequired[str]

class KnownFraudsterRiskTypeDef(TypedDict):
    RiskScore: int
    GeneratedFraudsterId: NotRequired[str]

class VoiceSpoofingRiskTypeDef(TypedDict):
    RiskScore: int

class JobProgressTypeDef(TypedDict):
    PercentComplete: NotRequired[int]

class InputDataConfigTypeDef(TypedDict):
    S3Uri: str

class OutputDataConfigTypeDef(TypedDict):
    S3Uri: str
    KmsKeyId: NotRequired[str]

class RegistrationConfigOutputTypeDef(TypedDict):
    DuplicateRegistrationAction: NotRequired[DuplicateRegistrationActionType]
    FraudsterSimilarityThreshold: NotRequired[int]
    WatchlistIds: NotRequired[List[str]]

class FraudsterSummaryTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DomainId: NotRequired[str]
    GeneratedFraudsterId: NotRequired[str]
    WatchlistIds: NotRequired[List[str]]

class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]

class ListDomainsRequestTypeDef(TypedDict):
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]

class ListFraudsterRegistrationJobsRequestTypeDef(TypedDict):
    DomainId: str
    JobStatus: NotRequired[FraudsterRegistrationJobStatusType]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]

class ListFraudstersRequestTypeDef(TypedDict):
    DomainId: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]
    WatchlistId: NotRequired[str]

class ListSpeakerEnrollmentJobsRequestTypeDef(TypedDict):
    DomainId: str
    JobStatus: NotRequired[SpeakerEnrollmentJobStatusType]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]

class ListSpeakersRequestTypeDef(TypedDict):
    DomainId: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]

class SpeakerSummaryTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    CustomerSpeakerId: NotRequired[str]
    DomainId: NotRequired[str]
    GeneratedSpeakerId: NotRequired[str]
    LastAccessedAt: NotRequired[datetime]
    Status: NotRequired[SpeakerStatusType]
    UpdatedAt: NotRequired[datetime]

class ListTagsForResourceRequestTypeDef(TypedDict):
    ResourceArn: str

class ListWatchlistsRequestTypeDef(TypedDict):
    DomainId: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]

class WatchlistSummaryTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DefaultWatchlist: NotRequired[bool]
    Description: NotRequired[str]
    DomainId: NotRequired[str]
    Name: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    WatchlistId: NotRequired[str]

class OptOutSpeakerRequestTypeDef(TypedDict):
    DomainId: str
    SpeakerId: str

class RegistrationConfigTypeDef(TypedDict):
    DuplicateRegistrationAction: NotRequired[DuplicateRegistrationActionType]
    FraudsterSimilarityThreshold: NotRequired[int]
    WatchlistIds: NotRequired[Sequence[str]]

class UntagResourceRequestTypeDef(TypedDict):
    ResourceArn: str
    TagKeys: Sequence[str]

class UpdateWatchlistRequestTypeDef(TypedDict):
    DomainId: str
    WatchlistId: str
    Description: NotRequired[str]
    Name: NotRequired[str]

class AssociateFraudsterResponseTypeDef(TypedDict):
    Fraudster: FraudsterTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class DescribeFraudsterResponseTypeDef(TypedDict):
    Fraudster: FraudsterTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class DisassociateFraudsterResponseTypeDef(TypedDict):
    Fraudster: FraudsterTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class EmptyResponseMetadataTypeDef(TypedDict):
    ResponseMetadata: ResponseMetadataTypeDef

class AuthenticationResultTypeDef(TypedDict):
    AudioAggregationEndedAt: NotRequired[datetime]
    AudioAggregationStartedAt: NotRequired[datetime]
    AuthenticationResultId: NotRequired[str]
    Configuration: NotRequired[AuthenticationConfigurationTypeDef]
    CustomerSpeakerId: NotRequired[str]
    Decision: NotRequired[AuthenticationDecisionType]
    GeneratedSpeakerId: NotRequired[str]
    Score: NotRequired[int]

class UpdateDomainRequestTypeDef(TypedDict):
    DomainId: str
    Name: str
    ServerSideEncryptionConfiguration: ServerSideEncryptionConfigurationTypeDef
    Description: NotRequired[str]

class CreateDomainRequestTypeDef(TypedDict):
    Name: str
    ServerSideEncryptionConfiguration: ServerSideEncryptionConfigurationTypeDef
    ClientToken: NotRequired[str]
    Description: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]

class ListTagsForResourceResponseTypeDef(TypedDict):
    Tags: List[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

class TagResourceRequestTypeDef(TypedDict):
    ResourceArn: str
    Tags: Sequence[TagTypeDef]

class CreateWatchlistResponseTypeDef(TypedDict):
    Watchlist: WatchlistTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class DescribeWatchlistResponseTypeDef(TypedDict):
    Watchlist: WatchlistTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateWatchlistResponseTypeDef(TypedDict):
    Watchlist: WatchlistTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class DescribeSpeakerResponseTypeDef(TypedDict):
    Speaker: SpeakerTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class OptOutSpeakerResponseTypeDef(TypedDict):
    Speaker: SpeakerTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class DomainSummaryTypeDef(TypedDict):
    Arn: NotRequired[str]
    CreatedAt: NotRequired[datetime]
    Description: NotRequired[str]
    DomainId: NotRequired[str]
    DomainStatus: NotRequired[DomainStatusType]
    Name: NotRequired[str]
    ServerSideEncryptionConfiguration: NotRequired[ServerSideEncryptionConfigurationTypeDef]
    ServerSideEncryptionUpdateDetails: NotRequired[ServerSideEncryptionUpdateDetailsTypeDef]
    UpdatedAt: NotRequired[datetime]
    WatchlistDetails: NotRequired[WatchlistDetailsTypeDef]

class DomainTypeDef(TypedDict):
    Arn: NotRequired[str]
    CreatedAt: NotRequired[datetime]
    Description: NotRequired[str]
    DomainId: NotRequired[str]
    DomainStatus: NotRequired[DomainStatusType]
    Name: NotRequired[str]
    ServerSideEncryptionConfiguration: NotRequired[ServerSideEncryptionConfigurationTypeDef]
    ServerSideEncryptionUpdateDetails: NotRequired[ServerSideEncryptionUpdateDetailsTypeDef]
    UpdatedAt: NotRequired[datetime]
    WatchlistDetails: NotRequired[WatchlistDetailsTypeDef]

class EnrollmentConfigOutputTypeDef(TypedDict):
    ExistingEnrollmentAction: NotRequired[ExistingEnrollmentActionType]
    FraudDetectionConfig: NotRequired[EnrollmentJobFraudDetectionConfigOutputTypeDef]

class EnrollmentConfigTypeDef(TypedDict):
    ExistingEnrollmentAction: NotRequired[ExistingEnrollmentActionType]
    FraudDetectionConfig: NotRequired[EnrollmentJobFraudDetectionConfigTypeDef]

class FraudRiskDetailsTypeDef(TypedDict):
    KnownFraudsterRisk: KnownFraudsterRiskTypeDef
    VoiceSpoofingRisk: VoiceSpoofingRiskTypeDef

class FraudsterRegistrationJobSummaryTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DomainId: NotRequired[str]
    EndedAt: NotRequired[datetime]
    FailureDetails: NotRequired[FailureDetailsTypeDef]
    JobId: NotRequired[str]
    JobName: NotRequired[str]
    JobProgress: NotRequired[JobProgressTypeDef]
    JobStatus: NotRequired[FraudsterRegistrationJobStatusType]

class SpeakerEnrollmentJobSummaryTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DomainId: NotRequired[str]
    EndedAt: NotRequired[datetime]
    FailureDetails: NotRequired[FailureDetailsTypeDef]
    JobId: NotRequired[str]
    JobName: NotRequired[str]
    JobProgress: NotRequired[JobProgressTypeDef]
    JobStatus: NotRequired[SpeakerEnrollmentJobStatusType]

class FraudsterRegistrationJobTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DataAccessRoleArn: NotRequired[str]
    DomainId: NotRequired[str]
    EndedAt: NotRequired[datetime]
    FailureDetails: NotRequired[FailureDetailsTypeDef]
    InputDataConfig: NotRequired[InputDataConfigTypeDef]
    JobId: NotRequired[str]
    JobName: NotRequired[str]
    JobProgress: NotRequired[JobProgressTypeDef]
    JobStatus: NotRequired[FraudsterRegistrationJobStatusType]
    OutputDataConfig: NotRequired[OutputDataConfigTypeDef]
    RegistrationConfig: NotRequired[RegistrationConfigOutputTypeDef]

class ListFraudstersResponseTypeDef(TypedDict):
    FraudsterSummaries: List[FraudsterSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

class ListDomainsRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListFraudsterRegistrationJobsRequestPaginateTypeDef(TypedDict):
    DomainId: str
    JobStatus: NotRequired[FraudsterRegistrationJobStatusType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListFraudstersRequestPaginateTypeDef(TypedDict):
    DomainId: str
    WatchlistId: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListSpeakerEnrollmentJobsRequestPaginateTypeDef(TypedDict):
    DomainId: str
    JobStatus: NotRequired[SpeakerEnrollmentJobStatusType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListSpeakersRequestPaginateTypeDef(TypedDict):
    DomainId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListWatchlistsRequestPaginateTypeDef(TypedDict):
    DomainId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListSpeakersResponseTypeDef(TypedDict):
    SpeakerSummaries: List[SpeakerSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

class ListWatchlistsResponseTypeDef(TypedDict):
    WatchlistSummaries: List[WatchlistSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

RegistrationConfigUnionTypeDef = Union[RegistrationConfigTypeDef, RegistrationConfigOutputTypeDef]

class ListDomainsResponseTypeDef(TypedDict):
    DomainSummaries: List[DomainSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

class CreateDomainResponseTypeDef(TypedDict):
    Domain: DomainTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class DescribeDomainResponseTypeDef(TypedDict):
    Domain: DomainTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateDomainResponseTypeDef(TypedDict):
    Domain: DomainTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class SpeakerEnrollmentJobTypeDef(TypedDict):
    CreatedAt: NotRequired[datetime]
    DataAccessRoleArn: NotRequired[str]
    DomainId: NotRequired[str]
    EndedAt: NotRequired[datetime]
    EnrollmentConfig: NotRequired[EnrollmentConfigOutputTypeDef]
    FailureDetails: NotRequired[FailureDetailsTypeDef]
    InputDataConfig: NotRequired[InputDataConfigTypeDef]
    JobId: NotRequired[str]
    JobName: NotRequired[str]
    JobProgress: NotRequired[JobProgressTypeDef]
    JobStatus: NotRequired[SpeakerEnrollmentJobStatusType]
    OutputDataConfig: NotRequired[OutputDataConfigTypeDef]

EnrollmentConfigUnionTypeDef = Union[EnrollmentConfigTypeDef, EnrollmentConfigOutputTypeDef]

class FraudDetectionResultTypeDef(TypedDict):
    AudioAggregationEndedAt: NotRequired[datetime]
    AudioAggregationStartedAt: NotRequired[datetime]
    Configuration: NotRequired[FraudDetectionConfigurationTypeDef]
    Decision: NotRequired[FraudDetectionDecisionType]
    FraudDetectionResultId: NotRequired[str]
    Reasons: NotRequired[List[FraudDetectionReasonType]]
    RiskDetails: NotRequired[FraudRiskDetailsTypeDef]

class ListFraudsterRegistrationJobsResponseTypeDef(TypedDict):
    JobSummaries: List[FraudsterRegistrationJobSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

class ListSpeakerEnrollmentJobsResponseTypeDef(TypedDict):
    JobSummaries: List[SpeakerEnrollmentJobSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

class DescribeFraudsterRegistrationJobResponseTypeDef(TypedDict):
    Job: FraudsterRegistrationJobTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class StartFraudsterRegistrationJobResponseTypeDef(TypedDict):
    Job: FraudsterRegistrationJobTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class StartFraudsterRegistrationJobRequestTypeDef(TypedDict):
    DataAccessRoleArn: str
    DomainId: str
    InputDataConfig: InputDataConfigTypeDef
    OutputDataConfig: OutputDataConfigTypeDef
    ClientToken: NotRequired[str]
    JobName: NotRequired[str]
    RegistrationConfig: NotRequired[RegistrationConfigUnionTypeDef]

class DescribeSpeakerEnrollmentJobResponseTypeDef(TypedDict):
    Job: SpeakerEnrollmentJobTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class StartSpeakerEnrollmentJobResponseTypeDef(TypedDict):
    Job: SpeakerEnrollmentJobTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class StartSpeakerEnrollmentJobRequestTypeDef(TypedDict):
    DataAccessRoleArn: str
    DomainId: str
    InputDataConfig: InputDataConfigTypeDef
    OutputDataConfig: OutputDataConfigTypeDef
    ClientToken: NotRequired[str]
    EnrollmentConfig: NotRequired[EnrollmentConfigUnionTypeDef]
    JobName: NotRequired[str]

class EvaluateSessionResponseTypeDef(TypedDict):
    AuthenticationResult: AuthenticationResultTypeDef
    DomainId: str
    FraudDetectionResult: FraudDetectionResultTypeDef
    SessionId: str
    SessionName: str
    StreamingStatus: StreamingStatusType
    ResponseMetadata: ResponseMetadataTypeDef



"""
Main interface for voice-id service.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_voice_id import (
        Client,
        ListDomainsPaginator,
        ListFraudsterRegistrationJobsPaginator,
        ListFraudstersPaginator,
        ListSpeakerEnrollmentJobsPaginator,
        ListSpeakersPaginator,
        ListWatchlistsPaginator,
        VoiceIDClient,
    )

    session = Session()
    client: VoiceIDClient = session.client("voice-id")

    list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
    list_fraudster_registration_jobs_paginator: ListFraudsterRegistrationJobsPaginator = client.get_paginator("list_fraudster_registration_jobs")
    list_fraudsters_paginator: ListFraudstersPaginator = client.get_paginator("list_fraudsters")
    list_speaker_enrollment_jobs_paginator: ListSpeakerEnrollmentJobsPaginator = client.get_paginator("list_speaker_enrollment_jobs")
    list_speakers_paginator: ListSpeakersPaginator = client.get_paginator("list_speakers")
    list_watchlists_paginator: ListWatchlistsPaginator = client.get_paginator("list_watchlists")
    ```
"""

from .client import VoiceIDClient
from .paginator import (
    ListDomainsPaginator,
    ListFraudsterRegistrationJobsPaginator,
    ListFraudstersPaginator,
    ListSpeakerEnrollmentJobsPaginator,
    ListSpeakersPaginator,
    ListWatchlistsPaginator,
)

Client = VoiceIDClient

__all__ = (
    "Client",
    "ListDomainsPaginator",
    "ListFraudsterRegistrationJobsPaginator",
    "ListFraudstersPaginator",
    "ListSpeakerEnrollmentJobsPaginator",
    "ListSpeakersPaginator",
    "ListWatchlistsPaginator",
    "VoiceIDClient",
)



"""
Type annotations for voice-id service Client.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_voice_id.client import VoiceIDClient

    session = Session()
    client: VoiceIDClient = session.client("voice-id")
    ```
"""

from __future__ import annotations

import sys
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    ListDomainsPaginator,
    ListFraudsterRegistrationJobsPaginator,
    ListFraudstersPaginator,
    ListSpeakerEnrollmentJobsPaginator,
    ListSpeakersPaginator,
    ListWatchlistsPaginator,
)
from .type_defs import (
    AssociateFraudsterRequestTypeDef,
    AssociateFraudsterResponseTypeDef,
    CreateDomainRequestTypeDef,
    CreateDomainResponseTypeDef,
    CreateWatchlistRequestTypeDef,
    CreateWatchlistResponseTypeDef,
    DeleteDomainRequestTypeDef,
    DeleteFraudsterRequestTypeDef,
    DeleteSpeakerRequestTypeDef,
    DeleteWatchlistRequestTypeDef,
    DescribeDomainRequestTypeDef,
    DescribeDomainResponseTypeDef,
    DescribeFraudsterRegistrationJobRequestTypeDef,
    DescribeFraudsterRegistrationJobResponseTypeDef,
    DescribeFraudsterRequestTypeDef,
    DescribeFraudsterResponseTypeDef,
    DescribeSpeakerEnrollmentJobRequestTypeDef,
    DescribeSpeakerEnrollmentJobResponseTypeDef,
    DescribeSpeakerRequestTypeDef,
    DescribeSpeakerResponseTypeDef,
    DescribeWatchlistRequestTypeDef,
    DescribeWatchlistResponseTypeDef,
    DisassociateFraudsterRequestTypeDef,
    DisassociateFraudsterResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    EvaluateSessionRequestTypeDef,
    EvaluateSessionResponseTypeDef,
    ListDomainsRequestTypeDef,
    ListDomainsResponseTypeDef,
    ListFraudsterRegistrationJobsRequestTypeDef,
    ListFraudsterRegistrationJobsResponseTypeDef,
    ListFraudstersRequestTypeDef,
    ListFraudstersResponseTypeDef,
    ListSpeakerEnrollmentJobsRequestTypeDef,
    ListSpeakerEnrollmentJobsResponseTypeDef,
    ListSpeakersRequestTypeDef,
    ListSpeakersResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListWatchlistsRequestTypeDef,
    ListWatchlistsResponseTypeDef,
    OptOutSpeakerRequestTypeDef,
    OptOutSpeakerResponseTypeDef,
    StartFraudsterRegistrationJobRequestTypeDef,
    StartFraudsterRegistrationJobResponseTypeDef,
    StartSpeakerEnrollmentJobRequestTypeDef,
    StartSpeakerEnrollmentJobResponseTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateDomainRequestTypeDef,
    UpdateDomainResponseTypeDef,
    UpdateWatchlistRequestTypeDef,
    UpdateWatchlistResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("VoiceIDClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class VoiceIDClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id.html#VoiceID.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        VoiceIDClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id.html#VoiceID.Client)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/can_paginate.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/generate_presigned_url.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#generate_presigned_url)
        """

    def associate_fraudster(
        self, **kwargs: Unpack[AssociateFraudsterRequestTypeDef]
    ) -> AssociateFraudsterResponseTypeDef:
        """
        Associates the fraudsters with the watchlist specified in the same domain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/associate_fraudster.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#associate_fraudster)
        """

    def create_domain(
        self, **kwargs: Unpack[CreateDomainRequestTypeDef]
    ) -> CreateDomainResponseTypeDef:
        """
        Creates a domain that contains all Amazon Connect Voice ID data, such as
        speakers, fraudsters, customer audio, and voiceprints.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/create_domain.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#create_domain)
        """

    def create_watchlist(
        self, **kwargs: Unpack[CreateWatchlistRequestTypeDef]
    ) -> CreateWatchlistResponseTypeDef:
        """
        Creates a watchlist that fraudsters can be a part of.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/create_watchlist.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#create_watchlist)
        """

    def delete_domain(
        self, **kwargs: Unpack[DeleteDomainRequestTypeDef]
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified domain from Voice ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/delete_domain.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#delete_domain)
        """

    def delete_fraudster(
        self, **kwargs: Unpack[DeleteFraudsterRequestTypeDef]
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified fraudster from Voice ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/delete_fraudster.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#delete_fraudster)
        """

    def delete_speaker(
        self, **kwargs: Unpack[DeleteSpeakerRequestTypeDef]
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified speaker from Voice ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/delete_speaker.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#delete_speaker)
        """

    def delete_watchlist(
        self, **kwargs: Unpack[DeleteWatchlistRequestTypeDef]
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified watchlist from Voice ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/delete_watchlist.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#delete_watchlist)
        """

    def describe_domain(
        self, **kwargs: Unpack[DescribeDomainRequestTypeDef]
    ) -> DescribeDomainResponseTypeDef:
        """
        Describes the specified domain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/describe_domain.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#describe_domain)
        """

    def describe_fraudster(
        self, **kwargs: Unpack[DescribeFraudsterRequestTypeDef]
    ) -> DescribeFraudsterResponseTypeDef:
        """
        Describes the specified fraudster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/describe_fraudster.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#describe_fraudster)
        """

    def describe_fraudster_registration_job(
        self, **kwargs: Unpack[DescribeFraudsterRegistrationJobRequestTypeDef]
    ) -> DescribeFraudsterRegistrationJobResponseTypeDef:
        """
        Describes the specified fraudster registration job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/describe_fraudster_registration_job.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#describe_fraudster_registration_job)
        """

    def describe_speaker(
        self, **kwargs: Unpack[DescribeSpeakerRequestTypeDef]
    ) -> DescribeSpeakerResponseTypeDef:
        """
        Describes the specified speaker.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/describe_speaker.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#describe_speaker)
        """

    def describe_speaker_enrollment_job(
        self, **kwargs: Unpack[DescribeSpeakerEnrollmentJobRequestTypeDef]
    ) -> DescribeSpeakerEnrollmentJobResponseTypeDef:
        """
        Describes the specified speaker enrollment job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/describe_speaker_enrollment_job.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#describe_speaker_enrollment_job)
        """

    def describe_watchlist(
        self, **kwargs: Unpack[DescribeWatchlistRequestTypeDef]
    ) -> DescribeWatchlistResponseTypeDef:
        """
        Describes the specified watchlist.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/describe_watchlist.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#describe_watchlist)
        """

    def disassociate_fraudster(
        self, **kwargs: Unpack[DisassociateFraudsterRequestTypeDef]
    ) -> DisassociateFraudsterResponseTypeDef:
        """
        Disassociates the fraudsters from the watchlist specified.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/disassociate_fraudster.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#disassociate_fraudster)
        """

    def evaluate_session(
        self, **kwargs: Unpack[EvaluateSessionRequestTypeDef]
    ) -> EvaluateSessionResponseTypeDef:
        """
        Evaluates a specified session based on audio data accumulated during a
        streaming Amazon Connect Voice ID call.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/evaluate_session.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#evaluate_session)
        """

    def list_domains(
        self, **kwargs: Unpack[ListDomainsRequestTypeDef]
    ) -> ListDomainsResponseTypeDef:
        """
        Lists all the domains in the Amazon Web Services account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_domains.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_domains)
        """

    def list_fraudster_registration_jobs(
        self, **kwargs: Unpack[ListFraudsterRegistrationJobsRequestTypeDef]
    ) -> ListFraudsterRegistrationJobsResponseTypeDef:
        """
        Lists all the fraudster registration jobs in the domain with the given
        <code>JobStatus</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_fraudster_registration_jobs.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_fraudster_registration_jobs)
        """

    def list_fraudsters(
        self, **kwargs: Unpack[ListFraudstersRequestTypeDef]
    ) -> ListFraudstersResponseTypeDef:
        """
        Lists all fraudsters in a specified watchlist or domain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_fraudsters.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_fraudsters)
        """

    def list_speaker_enrollment_jobs(
        self, **kwargs: Unpack[ListSpeakerEnrollmentJobsRequestTypeDef]
    ) -> ListSpeakerEnrollmentJobsResponseTypeDef:
        """
        Lists all the speaker enrollment jobs in the domain with the specified
        <code>JobStatus</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_speaker_enrollment_jobs.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_speaker_enrollment_jobs)
        """

    def list_speakers(
        self, **kwargs: Unpack[ListSpeakersRequestTypeDef]
    ) -> ListSpeakersResponseTypeDef:
        """
        Lists all speakers in a specified domain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_speakers.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_speakers)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Lists all tags associated with a specified Voice ID resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_tags_for_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_tags_for_resource)
        """

    def list_watchlists(
        self, **kwargs: Unpack[ListWatchlistsRequestTypeDef]
    ) -> ListWatchlistsResponseTypeDef:
        """
        Lists all watchlists in a specified domain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/list_watchlists.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#list_watchlists)
        """

    def opt_out_speaker(
        self, **kwargs: Unpack[OptOutSpeakerRequestTypeDef]
    ) -> OptOutSpeakerResponseTypeDef:
        """
        Opts out a speaker from Voice ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/opt_out_speaker.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#opt_out_speaker)
        """

    def start_fraudster_registration_job(
        self, **kwargs: Unpack[StartFraudsterRegistrationJobRequestTypeDef]
    ) -> StartFraudsterRegistrationJobResponseTypeDef:
        """
        Starts a new batch fraudster registration job using provided details.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/start_fraudster_registration_job.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#start_fraudster_registration_job)
        """

    def start_speaker_enrollment_job(
        self, **kwargs: Unpack[StartSpeakerEnrollmentJobRequestTypeDef]
    ) -> StartSpeakerEnrollmentJobResponseTypeDef:
        """
        Starts a new batch speaker enrollment job using specified details.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/start_speaker_enrollment_job.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#start_speaker_enrollment_job)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Tags a Voice ID resource with the provided list of tags.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/tag_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Removes specified tags from a specified Amazon Connect Voice ID resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/untag_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#untag_resource)
        """

    def update_domain(
        self, **kwargs: Unpack[UpdateDomainRequestTypeDef]
    ) -> UpdateDomainResponseTypeDef:
        """
        Updates the specified domain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/update_domain.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#update_domain)
        """

    def update_watchlist(
        self, **kwargs: Unpack[UpdateWatchlistRequestTypeDef]
    ) -> UpdateWatchlistResponseTypeDef:
        """
        Updates the specified watchlist.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/update_watchlist.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#update_watchlist)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_domains"]
    ) -> ListDomainsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_fraudster_registration_jobs"]
    ) -> ListFraudsterRegistrationJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_fraudsters"]
    ) -> ListFraudstersPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_speaker_enrollment_jobs"]
    ) -> ListSpeakerEnrollmentJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_speakers"]
    ) -> ListSpeakersPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_watchlists"]
    ) -> ListWatchlistsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/client/#get_paginator)
        """



"""
Type annotations for voice-id service client paginators.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from mypy_boto3_voice_id.client import VoiceIDClient
    from mypy_boto3_voice_id.paginator import (
        ListDomainsPaginator,
        ListFraudsterRegistrationJobsPaginator,
        ListFraudstersPaginator,
        ListSpeakerEnrollmentJobsPaginator,
        ListSpeakersPaginator,
        ListWatchlistsPaginator,
    )

    session = Session()
    client: VoiceIDClient = session.client("voice-id")

    list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
    list_fraudster_registration_jobs_paginator: ListFraudsterRegistrationJobsPaginator = client.get_paginator("list_fraudster_registration_jobs")
    list_fraudsters_paginator: ListFraudstersPaginator = client.get_paginator("list_fraudsters")
    list_speaker_enrollment_jobs_paginator: ListSpeakerEnrollmentJobsPaginator = client.get_paginator("list_speaker_enrollment_jobs")
    list_speakers_paginator: ListSpeakersPaginator = client.get_paginator("list_speakers")
    list_watchlists_paginator: ListWatchlistsPaginator = client.get_paginator("list_watchlists")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListDomainsRequestPaginateTypeDef,
    ListDomainsResponseTypeDef,
    ListFraudsterRegistrationJobsRequestPaginateTypeDef,
    ListFraudsterRegistrationJobsResponseTypeDef,
    ListFraudstersRequestPaginateTypeDef,
    ListFraudstersResponseTypeDef,
    ListSpeakerEnrollmentJobsRequestPaginateTypeDef,
    ListSpeakerEnrollmentJobsResponseTypeDef,
    ListSpeakersRequestPaginateTypeDef,
    ListSpeakersResponseTypeDef,
    ListWatchlistsRequestPaginateTypeDef,
    ListWatchlistsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListDomainsPaginator",
    "ListFraudsterRegistrationJobsPaginator",
    "ListFraudstersPaginator",
    "ListSpeakerEnrollmentJobsPaginator",
    "ListSpeakersPaginator",
    "ListWatchlistsPaginator",
)


if TYPE_CHECKING:
    _ListDomainsPaginatorBase = Paginator[ListDomainsResponseTypeDef]
else:
    _ListDomainsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDomainsPaginator(_ListDomainsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListDomains.html#VoiceID.Paginator.ListDomains)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listdomainspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDomainsRequestPaginateTypeDef]
    ) -> PageIterator[ListDomainsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListDomains.html#VoiceID.Paginator.ListDomains.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listdomainspaginator)
        """


if TYPE_CHECKING:
    _ListFraudsterRegistrationJobsPaginatorBase = Paginator[
        ListFraudsterRegistrationJobsResponseTypeDef
    ]
else:
    _ListFraudsterRegistrationJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListFraudsterRegistrationJobsPaginator(_ListFraudsterRegistrationJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListFraudsterRegistrationJobs.html#VoiceID.Paginator.ListFraudsterRegistrationJobs)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listfraudsterregistrationjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFraudsterRegistrationJobsRequestPaginateTypeDef]
    ) -> PageIterator[ListFraudsterRegistrationJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListFraudsterRegistrationJobs.html#VoiceID.Paginator.ListFraudsterRegistrationJobs.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listfraudsterregistrationjobspaginator)
        """


if TYPE_CHECKING:
    _ListFraudstersPaginatorBase = Paginator[ListFraudstersResponseTypeDef]
else:
    _ListFraudstersPaginatorBase = Paginator  # type: ignore[assignment]


class ListFraudstersPaginator(_ListFraudstersPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListFraudsters.html#VoiceID.Paginator.ListFraudsters)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listfraudsterspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFraudstersRequestPaginateTypeDef]
    ) -> PageIterator[ListFraudstersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListFraudsters.html#VoiceID.Paginator.ListFraudsters.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listfraudsterspaginator)
        """


if TYPE_CHECKING:
    _ListSpeakerEnrollmentJobsPaginatorBase = Paginator[ListSpeakerEnrollmentJobsResponseTypeDef]
else:
    _ListSpeakerEnrollmentJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListSpeakerEnrollmentJobsPaginator(_ListSpeakerEnrollmentJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListSpeakerEnrollmentJobs.html#VoiceID.Paginator.ListSpeakerEnrollmentJobs)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listspeakerenrollmentjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSpeakerEnrollmentJobsRequestPaginateTypeDef]
    ) -> PageIterator[ListSpeakerEnrollmentJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListSpeakerEnrollmentJobs.html#VoiceID.Paginator.ListSpeakerEnrollmentJobs.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listspeakerenrollmentjobspaginator)
        """


if TYPE_CHECKING:
    _ListSpeakersPaginatorBase = Paginator[ListSpeakersResponseTypeDef]
else:
    _ListSpeakersPaginatorBase = Paginator  # type: ignore[assignment]


class ListSpeakersPaginator(_ListSpeakersPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListSpeakers.html#VoiceID.Paginator.ListSpeakers)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listspeakerspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSpeakersRequestPaginateTypeDef]
    ) -> PageIterator[ListSpeakersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListSpeakers.html#VoiceID.Paginator.ListSpeakers.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listspeakerspaginator)
        """


if TYPE_CHECKING:
    _ListWatchlistsPaginatorBase = Paginator[ListWatchlistsResponseTypeDef]
else:
    _ListWatchlistsPaginatorBase = Paginator  # type: ignore[assignment]


class ListWatchlistsPaginator(_ListWatchlistsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListWatchlists.html#VoiceID.Paginator.ListWatchlists)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listwatchlistspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListWatchlistsRequestPaginateTypeDef]
    ) -> PageIterator[ListWatchlistsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id/paginator/ListWatchlists.html#VoiceID.Paginator.ListWatchlists.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_voice_id/paginators/#listwatchlistspaginator)
        """
